.. AUTO-GENERATED FILE -- DO NOT EDIT!

auth.ioloop
===========

Module: :mod:`auth.ioloop`
--------------------------
.. automodule:: zmq.auth.ioloop

.. currentmodule:: zmq.auth.ioloop

:class:`IOLoopAuthenticator`
----------------------------


.. autoclass:: IOLoopAuthenticator
  :members:
  :undoc-members:
  :inherited-members:

